@@ -1,3 +1,38 @@
+globalVariables(c(
+  "palette","gray","par","layout","axis","rect"
+))
+
+#' Plot Levels of a Variable in a Colour-Coded Map
+#' 
+#' @description Plot levels of a variable in a colour-coded map along with a legend.
+#' 
+#' @param y variable to plot
+#' @param spatial.polygon an object of class SpatialPolygons (See \link[sp]{SpatialPolygons-class})
+#' @param ncut number of cuts in colour levels to plot
+#' @param nlevels number of levels to include in legend
+#' @param lower lower bound of levels
+#' @param upper upper bound of levels
+#' @param main an overall title for the plot
+#' @param xlab a title for the x axis
+#' @param ylab a title for the y axis
+#'
+#' @references Bivand, R. S., Pebesma E. J., and Gomez-Rubio V. (2008) \emph{Applied Spatial Data Analysis with R}.  Springer Series in Statistics.
+#' E. J. Pebesma and R. S. Bivand. (2005) Classes and methods for spatial data in R. \emph{R News}, \bold{5}, 9--13. 
+#' 
+#' @author Jon Wakefield, Nicky Best, Sebastien Haneuse, and Albert Y. Kim
+#' 
+#' @return A map colour-coded to indicate the different levels of \code{y}
+#' 
+#' @export
+#' @import sp
+#'
+#' @examples
+#' data(scotland)
+#' map <- scotland$spatial.polygon
+#' y <- scotland$data$cases
+#' E <- scotland$data$expected
+#' SMR <- y/E
+#' mapvariable(SMR,map,main="Scotland",xlab="Eastings (km)",ylab="Northings (km)")
 mapvariable <-
 function(y, spatial.polygon, ncut=1000, nlevels=10, lower=NULL, upper=NULL, 
          main=NULL, xlab=NULL, ylab=NULL){
